/**
 *
 */
package org.jboss.cache;

import java.util.Map;

/**
 * Base class for {@link UnversionedNode}.
 *
 * @author manik
 */
public abstract class AbstractNode<K, V>// implements Node<K, V>
{
   protected boolean deleted;
   protected Map<Object, Node<K, V>> children;
   protected Fqn<?> fqn;
   protected boolean resident;

   public boolean isDeleted()
   {
      return deleted;
   }

   public void markAsDeleted(boolean marker)
   {
      markAsDeleted(marker, false);
   }

   public void markAsDeleted(boolean marker, boolean recursive)
   {
      deleted = marker;
      if (recursive && children != null)
      {
         synchronized (this)
         {
            for (Node<?, ?> child : children.values())
            {
               ((NodeSPI) child).markAsDeleted(marker, true);
            }
         }
      }
   }

   public void setResident(boolean resident)
   {
      this.resident = resident;
   }


   public boolean isResident()
   {
      return resident;
   }


   public boolean equals(Object another)
   {
      if (another instanceof AbstractNode)
      {
         AbstractNode<?, ?> anotherNode = (AbstractNode) another;
         return fqn == null && anotherNode.fqn == null || !(fqn == null || anotherNode.fqn == null) && fqn.equals(anotherNode.fqn);
      }
      return false;
   }


   public int hashCode()
   {
      return fqn.hashCode();
   }
}
