package org.jboss.cache.interceptors;

import org.jboss.cache.InvocationContext;
import org.jboss.cache.transaction.GlobalTransaction;

/**
 * The interceptor in charge of firing off notifications to cache listeners
 *
 * @author <a href="mailto:manik@jboss.org">Manik Surtani</a>
 * @since 2.0.0
 */
public class NotificationInterceptor extends BaseTransactionalContextInterceptor
{
   public NotificationInterceptor()
   {
      initLogger();
   }

   @Override
   protected Object handleBlockChannelMethod(InvocationContext ctx) throws Throwable
   {
      cache.getNotifier().notifyCacheBlocked(cache, true);
      Object retVal = nextInterceptor(ctx);
      cache.getNotifier().notifyCacheBlocked(cache, false);
      return retVal;
   }

   @Override
   protected Object handleUnblockChannelMethod(InvocationContext ctx) throws Throwable
   {
      cache.getNotifier().notifyCacheUnblocked(cache, true);
      Object retval = nextInterceptor(ctx);
      cache.getNotifier().notifyCacheUnblocked(cache, false);
      return retval;
   }

   @Override
   protected Object handleCommitMethod(InvocationContext ctx, GlobalTransaction globalTransaction) throws Throwable
   {
      // notify commit
      // ctx.is
      Object retval = nextInterceptor(ctx);
      cache.getNotifier().notifyTransactionCompleted(ctx.getTransaction(), true, ctx);
      return retval;
   }

   @Override
   protected Object handleRollbackMethod(InvocationContext ctx, GlobalTransaction globalTransaction) throws Throwable
   {
      Object retval = nextInterceptor(ctx);
      cache.getNotifier().notifyTransactionCompleted(ctx.getTransaction(), false, ctx);
      return retval;
   }
}
