/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.lock;


/**
 * Factory to create LockStragtegy instance.
 *
 * @author Ben Wang
 */
public class LockStrategyFactory
{

   /**
    * Transaction locking isolation level. Default.
    */
   private static IsolationLevel lockingLevel_ = IsolationLevel.REPEATABLE_READ;

   /**
    *
    */
   protected LockStrategyFactory()
   {
   }

   public static LockStrategy getLockStrategy()
   {
      return getLockStrategy(lockingLevel_);
   }

   public static LockStrategy getLockStrategy(IsolationLevel lockingLevel)
   {
      //if(log_.isTraceEnabled()) {
      // log_.trace("LockStrategy is: " + lockingLevel);
      //}
      if (lockingLevel == null)
         return new LockStrategyNone();
      switch (lockingLevel)
      {
         case NONE:
            return new LockStrategyNone();
         case SERIALIZABLE:
            return new LockStrategySerializable();
         case READ_UNCOMMITTED:
            return new LockStrategyReadUncommitted();
         case READ_COMMITTED:
            return new LockStrategyReadCommitted();
         case REPEATABLE_READ:
         default:
            return new LockStrategyRepeatableRead();
      }
   }

   public static void setIsolationLevel(IsolationLevel level)
   {
      lockingLevel_ = level;
   }

}
